@@ -160,7 +160,7 @@ void cpp2uno_call(
     (*pThis->getUnoI()->pDispatcher)(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
     
-    // in case no exception occured...
+    // in case no exception occurred...
     if (pUnoExc)
     {
         // destruct temporary in/inout params
@@ -179,7 +179,7 @@ void cpp2uno_call(
             &aUnoExc, pThis->getBridge()->getUno2Cpp() );
             // has to destruct the any
     }
-    else // else no exception occured...
+    else // else no exception occurred...
     {
         // temporary params
         for ( ; nTempIndizes--; )
@@ -251,7 +251,7 @@ extern "C" void cpp_vtable_call(
                  "### illegal vtable index!" );
     if (nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex)
     {
-        throw RuntimeException( rtl::OUString::createFromAscii("illegal vtable index!"), (XInterface *)pThis );
+        throw RuntimeException( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "illegal vtable index!" )), (XInterface *)pThis );
     }
     
     // determine called method
@@ -340,7 +340,7 @@ extern "C" void cpp_vtable_call(
     }
     default:
     {
-        throw RuntimeException( rtl::OUString::createFromAscii("no member description found!"), (XInterface *)pThis );
+        throw RuntimeException( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "no member description found!" )), (XInterface *)pThis );
     }
     }
 }
