@@ -248,7 +248,7 @@ static void cpp_call(
             {
                 case typelib_TypeClass_HYPER:
                 case typelib_TypeClass_UNSIGNED_HYPER:
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
                     fprintf(stderr, "hyper is %llx\n", *((long long*)pCppArgs[nPos]));
 #endif
                     INSERT_INT64( pCppArgs[nPos], nRegs, pGPR, pStack, pStackStart, bOverFlow );
@@ -256,7 +256,7 @@ static void cpp_call(
                 case typelib_TypeClass_LONG:
                 case typelib_TypeClass_UNSIGNED_LONG:
                 case typelib_TypeClass_ENUM:
-#ifdef CMC_DEBUG
+#if OSL_DEBUG_LEVEL > 2
                     fprintf(stderr, "long is %x\n", pCppArgs[nPos]);
 #endif
                     INSERT_INT32( pCppArgs[nPos], nRegs, pGPR, pStack, bOverFlow );
@@ -323,7 +323,7 @@ static void cpp_call(
             pStackStart, 
             (pStack - pStackStart), pGPR, pFPR);
 
-        // NO exception occured...
+        // NO exception occurred...
         *ppUnoExc = 0;
 
         // reconvert temporary params
