@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -38,9 +39,12 @@
 
 #include "share.hxx"
 
-using namespace rtl;
 using namespace com::sun::star::uno;
 
+using ::rtl::OUString;
+using ::rtl::OString;
+using ::rtl::OUStringToOString;
+
 namespace
 {
 //==================================================================================================
@@ -412,7 +416,7 @@ static void cpp_call(
             pReturnTypeDescr->eTypeClass,
             (sal_Int32 *)pCppStackStart,
              nStackLongs);
-        // NO exception occured...
+        // NO exception occurred...
         *ppUnoExc = 0;
 
         // reconvert temporary params
@@ -598,3 +602,5 @@ void unoInterfaceProxyDispatch(
 }
 
 } } }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
