@@ -41,9 +41,12 @@
 
 #include <sal/alloca.h>
 
-using namespace rtl;
 using namespace com::sun::star::uno;
 
+using ::rtl::OUString;
+using ::rtl::OString;
+using ::rtl::OUStringToOString;
+
 namespace
 {
 //==================================================================================================
@@ -408,7 +411,7 @@ static void cpp_call(
             pReturnTypeDescr->eTypeClass,
             (sal_Int32 *)pCppStackStart,
              nStackLongs);
-        // NO exception occured...
+        // NO exception occurred...
         *ppUnoExc = 0;
 
         // reconvert temporary params
