@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -55,9 +56,11 @@ namespace sr = System::Reflection;
 namespace st = System::Text;
 namespace ucss = unoidl::com::sun::star;
 
-using namespace rtl;
 using namespace std;
 
+using ::rtl::OUString;
+using ::rtl::OUStringBuffer;
+
 
 namespace cli_uno
 {
@@ -2009,3 +2012,5 @@ void Bridge::map_to_cli(
     }
 }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
