@@ -45,7 +45,8 @@ using namespace com::sun::star;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::reflection;
-using namespace rtl;
+
+using ::rtl::OUString;
 
 namespace cppu {
     
