@@ -58,9 +58,12 @@
 #include "framework.hxx"
 #include "fwkutil.hxx"
 
-using namespace rtl;
 using namespace osl;
 
+using ::rtl::OUString;
+using ::rtl::OUStringToOString;
+using ::rtl::OString;
+
 namespace jfw
 {
 
