@@ -30,8 +30,9 @@
 #include	<osl/file.hxx>
 #include	<codemaker/typemanager.hxx>
 
-using namespace rtl;
-
+using ::rtl::OUString;
+using ::rtl::OString;
+using ::rtl::OStringToOUString;
 TypeManager::TypeManager()
 {
     m_pImpl = new TypeManagerImpl();
@@ -116,7 +117,7 @@ sal_Bool RegistryTypeManager::init(sal_Bool bMerged, const StringVector& regFile
             freeRegistries();
             return sal_False;
         }
-        iter++;
+        ++iter;
     }
 
     if (m_pImpl->m_isMerged)
@@ -145,7 +146,7 @@ sal_Bool RegistryTypeManager::init(sal_Bool bMerged, const StringVector& regFile
                         return sal_False;
                     }
                 }
-                iter++;
+                ++iter;
             }
             
             m_pImpl->m_pMergedRegistry = pTmpReg;
@@ -238,7 +239,7 @@ void RegistryTypeManager::freeRegistries()
     {
         delete *iter;
 
-        iter++;
+        ++iter;
     }	
 
 }	
@@ -265,7 +266,7 @@ RegistryKey	RegistryTypeManager::searchTypeKey(const OString& name)
                     break;
             }
 
-            iter++;
+            ++iter;
         }	
     }
     
