@@ -32,7 +32,8 @@
 #include <rtl/memory.h>
 
 #if defined(LINUX) || defined(SOLARIS) || defined(NETBSD) || \
-	defined(FREEBSD) || defined(MACOSX) || defined(OPENBSD)
+    defined(FREEBSD) || defined(MACOSX) || defined(OPENBSD) || \
+    defined(DRAGONFLY)
 #include <pthread.h>
 #ifndef MACOSX
  #include <locale.h>
@@ -234,7 +235,7 @@ static rtl_Locale * _parse_locale( const char * locale )
 }
         
 #if defined(LINUX) || defined(SOLARIS) || defined(NETBSD) || \
-	defined(FREEBSD) || defined(OPENBSD)
+    defined(FREEBSD) || defined(OPENBSD) || defined(DRAGONFLY)
 
 /*
  * This implementation of osl_getTextEncodingFromLocale maps
@@ -486,7 +487,7 @@ const _pair _nl_language_list[] = {
     { "WIN-SAMI-2",                 RTL_TEXTENCODING_DONTKNOW }     /* WS2 */
 };
 
-#elif defined(FREEBSD)
+#elif defined(FREEBSD) || defined(DRAGONFLY)
 
 const _pair _nl_language_list[] = {
     { "ASCII",         RTL_TEXTENCODING_ASCII_US       }, /* US-ASCII */
@@ -860,7 +861,6 @@ rtl_TextEncoding osl_getTextEncodingFromLocale( rtl_Locale * pLocale )
 /* OS X locale discovery function */
 int (*pGetOSXLocale)( char *, sal_uInt32 );
 
-oslModule SAL_CALL osl_psz_loadModule(const sal_Char *pszModuleName, sal_Int32 nRtldMode);
 /*****************************************************************************
  return the current process locale
  *****************************************************************************/
@@ -878,9 +878,9 @@ void _imp_getProcessLocale( rtl_Locale ** ppLocale )
     if ( NULL == locale )
     {
 
-        locale = (char *)malloc( 20 );
+        locale = (char *)malloc( 128 );
         if ( locale )
-            macosx_getLocale( locale, 20 );
+            macosx_getLocale( locale, 128 );
         else
             fprintf( stderr, "nlsupport.c:  locale allocation returned NULL!\n" );
     }
@@ -942,40 +942,28 @@ void _imp_getProcessLocale( rtl_Locale ** ppLocale )
  set the current process locale
  *****************************************************************************/
 
+static int
+_setenv (const char* name, const char* value)
+{
+    return setenv (name, value, 1);
+}
+
 int _imp_setProcessLocale( rtl_Locale * pLocale )
 {
     char locale_buf[64];
-    
+
     /* convert rtl_Locale to locale string */
     if( NULL != _compose_locale( pLocale, locale_buf, 64 ) )
     {
         /* only change env vars that exist already */
-        if( getenv( "LC_ALL" ) ) {
-#if defined( FREEBSD ) || defined( NETBSD ) || defined( MACOSX ) || \
-	defined( AIX ) || defined( OPENBSD )
-            setenv( "LC_ALL", locale_buf, 1);
-#else
-            setenv( "LC_ALL", locale_buf );
-#endif
-        }
+        if( getenv( "LC_ALL" ) )
+            _setenv( "LC_ALL", locale_buf );
 
-        if( getenv( "LC_CTYPE" ) ) {
-#if defined( FREEBSD ) || defined( NETBSD ) || defined( MACOSX ) || \
-	defined( AIX ) || defined( OPENBSD )
-            setenv("LC_CTYPE", locale_buf, 1 );
-#else
-            setenv( "LC_CTYPE", locale_buf );
-#endif
-        }
+        if( getenv( "LC_CTYPE" ) )
+            _setenv("LC_CTYPE", locale_buf );
 
-        if( getenv( "LANG" ) ) {
-#if defined( FREEBSD ) || defined( NETBSD ) || defined( MACOSX ) || \
-	defined( AIX ) || defined( OPENBSD)
-            setenv("LC_CTYPE", locale_buf, 1 );
-#else
-            setenv( "LANG", locale_buf );
-#endif
-        }
+        if( getenv( "LANG" ) )
+            _setenv( "LANG", locale_buf );
     }
 
     return 0;
