@@ -29,15 +29,9 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sal.hxx"
 
-//------------------------------------------------------------------------
-//------------------------------------------------------------------------
-
 #include <math.h>
 #include <stdlib.h>
 
-//------------------------------------------------------------------------
-//------------------------------------------------------------------------
-
 #ifndef _SAL_TYPES_H_
     #include <sal/types.h>
 #endif
@@ -50,18 +44,11 @@
     #include <rtl/string.hxx>
 #endif
 
-//------------------------------------------------------------------------
-//------------------------------------------------------------------------
-
 #ifndef _RTL_STRING_UTILS_CONST_H_
     #include <rtl_String_Utils_Const.h>
 #endif
 
-//------------------------------------------------------------------------
-//------------------------------------------------------------------------
-
-using namespace rtl;
-
+using ::rtl::OString;
 sal_uInt32 AStringLen( const sal_Char *pAStr )
 {
     sal_uInt32  nStrLen = 0;
@@ -277,11 +264,6 @@ sal_Bool AStringToDoubleCompare ( const sal_Char  *pStr,
     return cmp;
 } // AStringToDoubleCompare
 
-//------------------------------------------------------------------------
-
-
-//------------------------------------------------------------------------
-
 sal_uInt32 UStringLen( const sal_Unicode *pUStr )
 {
     sal_uInt32 nUStrLen = 0;
@@ -611,7 +593,4 @@ sal_Bool AStringToUStringNCopy( sal_Unicode       *pDest,
     return  bCopied;
 } // AStringToUStringNCopy
 
-//------------------------------------------------------------------------
-//------------------------------------------------------------------------
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
